@@ -1,10 +1,12 @@
 package Reflex::POE::Wheel::Run;
 BEGIN {
-  $Reflex::POE::Wheel::Run::VERSION = '0.072';
+  $Reflex::POE::Wheel::Run::VERSION = '0.080';
 }
 use Moose;
 extends 'Reflex::POE::Wheel';
 use POE::Wheel::Run;
+use Reflex::PID;
+use Reflex::Trait::Observed;
 
 # These are class methods, returning static class data.
 # TODO - What's the proper way to do this with Moose?
@@ -85,12 +87,9 @@ sub valid_params {
 
 # Also handle signals.
 
-use Reflex::PID;
-has sigchild_watcher => (
-	isa    => 'Reflex::PID|Undef',
-	is     => 'rw',
-	traits => ['Reflex::Trait::Observed'],
-	role   => 'sigchld',
+observes sigchild_watcher => (
+	isa   => 'Reflex::PID|Undef',
+	role  => 'sigchld',
 );
 
 sub BUILD {
@@ -125,7 +124,7 @@ Reflex::POE::Wheel::Run - Represent POE::Wheel::Run as a Reflex class.
 
 =head1 VERSION
 
-version 0.072
+version 0.080
 
 =head1 SYNOPSIS
 
@@ -134,10 +133,8 @@ the synopsis at this time.  Please see eg-07-wheel-run.pl and
 eg-08-observer-trait.pl in the distribution's eg directory for longer
 but fully executable ones.
 
-	has child => (
-		traits  => ['Reflex::Trait::Observed'],
-		isa     => 'Reflex::POE::Wheel::Run|Undef',
-		is      => 'rw',
+	observes child => (
+		isa => 'Reflex::POE::Wheel::Run|Undef',
 	);
 
 	sub BUILD {
